@@ -40,7 +40,7 @@ class CustomHttpRequest:
         if hasattr(e, "response"):
             message = e.response.text
             status_code = e.response.status_code
-            if status_code <= 500:
+            if status_code < 500:
                 event_id = "no_id"
             else:
                 event_id = capture_exception(e)
